---
next: false
sidebarDepth: 2
---

# Страница перехватчика
Перехватчик может использоваться для перехвата связи между приложениями с помощью `Intent`. Он работает как MITM между исходными и целевыми приложениями. Он предлагает полный функционал пользовательского интерфейса для редактирования `Intent`s (намерений).

::: tip Информация
Развитие перехватчика всё ещё продолжается. На данный момент он может перехватывать только активити.
:::

::: warning Предупреждение
Перехватчик работает только для _неявного_ намерения, где не указан компонент [приложения][app_component].
:::

_Смотрите также:_
- _[Common Intents](https://developer.android.com/guide/components/intents-common)_
- _[Намерения и фильтры намерений](https://developer.android.com/guide/components/intents-filters)_

## Фильтры намерений
Фильтры намерений (Intent filters) используются приложениями для указания какие задачи они могут выполнять, или задач, которые они собираются выполнять с помощью других приложений. Например, когда вы открываете PDF файл с помощью файлового менеджера, файловый менеджер попытается найти, какими приложениями открывается PDF. Чтобы найти правильные приложения, файловый менеджер создаст намерение с фильтрами, такими как MIME-тип и попросит систему извлечь соответствующие приложения, которые могут открыть этот фильтр. Система выполнит поиск в манифесте установленных приложений для соответствия фильтру и перечислит компоненты приложения, которые могут открыть этот фильтр (в нашем случае PDF). При этом либо файловый менеджер откроет нужный компонент приложения, либо использует вариант предложенный системой, чтобы открыть его. Если несколько компонентов приложения могут открыть его, а значение по умолчания не установлено, вы можете получить запрос на выбор нужного компонента приложения.

### Действие
Действие определяет общее действие для выполнения, например `android.intent.action.VIEW`. Приложения часто заявляют о соответствующих действиях в файле манифеста, чтобы поймать желаемые намерения. Действие особенно полезно для широковещательного намерения, где оно играет жизненно важное правило. В других случаях оно работает как начальный способ отфильтровать соответствующие компоненты приложений. Общие действия, такие как `android.intent.action.VIEW` и `android.intent.action.SEND` широко используются приложениями. Таким образом, установка только этого параметра может соответствовать большому количеству компонентов приложения.

### Данные
Данные, изначально известные как URI (Uniform Resource Identifier) определены в [RFC 2396](http://www.faqs.org/rfcs/rfc2396.html). Это могут быть веб-ссылки, расположение файла или специальная функция _контент_. Контент является функцией Android под управлением [контент-провайдеров][providers]. Данные часто связаны с [MIME-типом](#mime-типы).

Примеры:
```
http://search.disroot.org/?q=URI%20in%20Android%20scheme&categories=general&language=en-US
https://developer.android.com/reference/android/net/Uri
file:///sdcard/AppManager.apk
mailto:email@example.com
content://io.github.muntashirakon.AppManager.provider/23485af89b08d87e898a90c7e/AppManager.apk
```

### MIME-типы
MIME-тип [данных](#данные). Например, если поле данных установлено в `file:///sdcard/AppManager.apk`, то соответствующим MIME-типом может быть `application/vnd.android.package-archive`.

### Категории
Это похоже на [действие](#деиствие) в том смысле, что оно также используется системой для фильтрации компонентов приложений. Это не дает никаких дополнительных выгод. В отличие от _действия_, может быть больше одной категории. Нажатие на кнопку _плюс_ рядом с заголовком позволяет добавить больше категорий.

### Флаги
Флаги полезны для определения того, как система должна вести себя во время запуска или после запуска активити. Обычному пользователю следует избегать этого, поскольку это требует некоторого технического образования. Кнопка _плюс_ рядом с заголовком может быть использована для добавления одного или нескольких флагов.

### Extras
Extras это пары ключ-значение, используемые для предоставления дополнительной информации компоненту назначения. Вы можете добавить extras, используя кнопку _плюс_ рядом с названием.

## URI
Представляет все намерение как URI (например, ` intent://... `). Некоторые данные не могут быть преобразованы в строку, и в результате они могут не отображаться здесь.

## Соответствующие активити
Список всех компонентов активити, соответствующих намерению. Это внутреннее определение определяется системой (а не AM). Кнопка запуска рядом с каждым компонентом может быть использована для запуска их непосредственно с AM.

## Сбросить на значения по умолчанию
Сброс намерения до первоначального состояния. Это может не всегда работать так, как ожидалось.

## Отправить измененное намерение
Повторно отправить измененное намерение. Это может открыть список приложений, в котором необходимо выбрать нужное приложение. Результат, полученный от целевого приложения, будет отправлен в исходное приложение. В результате исходное приложение не будет знать о MITM.

[app_component]: ../faq/app-components.md#что-такое-компоненты-приложения
[providers]: ./app-details-page.md#поставщики
